@@ -10,6 +10,7 @@ import platform
 import sys
 import sysconfig
 from datetime import datetime
+import speedtest
 
 
 class CPU:
@@ -31,8 +32,8 @@ class CPU:
         return CPU.info['brand_raw']
     
     @staticmethod
-    def percent():
-        return psutil.cpu_percent(0.2) 
+    def percent(time=0.2):
+        return psutil.cpu_percent(time) 
     
     
 class Ram:
@@ -51,12 +52,16 @@ class Ram:
     def free_mem(acc):
         return round(Ram.mem.available/1000000000, acc)
     
+    @staticmethod
+    def refresh():
+        Ram.mem = psutil.virtual_memory()
+    
   
 class Disk:
     
     @staticmethod
     def list_disks(every = False):
-        return [{'device': i[0], 'mountpoint': i[1], 'fstype': i[2], 'opts': i[3]} for each in psutil.disk_partitions(all=every) if (i:=list(each))]
+        return [{'device': i[0], 'mountpoint': i[1], 'fstype': i[2], 'opts': i[3]} for each in psutil.disk_partitions(all=every) for i in list(each)]
 
     @staticmethod
     def get_size(bts, suffix="B"):
@@ -114,6 +119,24 @@ class Network:
         finally:
             s.close()
         return IP
+    
+    @staticmethod
+    def singlespeedtest():
+        s = speedtest.Speedtest()
+        s.get_servers()
+        s.get_best_server()
+        s.download()
+        s.upload()
+        res = s.results.dict()
+        return res["download"], res["upload"], res["ping"]
+
+    @staticmethod
+    def speedtest():
+        for i in range(3):
+            d, u, p = Network.singlespeedtest()
+            print('Test #{}\n'.format(i+1))
+            if i == 3:
+                return {'Download': d, 'Upload': u, 'Ping': p}
   
   
 class PythonInfo:
@@ -162,7 +185,7 @@ class System:
     
     @staticmethod
     def fans_rpm():
-        if platform.system == 'Linux':
+        if platform.system() == 'Linux':
             return psutil.sensors_fans()
         else:
             return None
@@ -170,10 +193,10 @@ class System:
     
     @staticmethod
     def temp(fahrenheit=False):
-        if platform.system == 'Linux':
+        if platform.system() == 'Linux':
             return psutil.sensors_temperatures(fahrenheit=fahrenheit)
-        else:
-            return None
+        elif platform.system() == 'Windows':
+            pass
     
     
     @staticmethod
